@@ -3,28 +3,19 @@ extern crate clap;
 
 pub mod print;
 pub mod error;
-
 pub mod m20;
 pub mod msl;
 pub mod nsyt;
 pub mod constants;
 pub mod calibfile;
-pub mod imagebuffer;
 pub mod path;
 pub mod decompanding;
-pub mod stats;
-pub mod inpaint;
+pub mod inpaintmask;
 pub mod enums;
 pub mod flatfield;
-pub mod rgbimage;
-pub mod debayer;
-pub mod noise;
 pub mod util;
-pub mod hotpixel;
 pub mod httpfetch;
 pub mod jsonfetch;
 pub mod time;
-pub mod cahvor;
-pub mod vector;
 pub mod metadata;
-pub mod matrix;
\ No newline at end of file
+pub mod image;
\ No newline at end of file
