@@ -1,6 +1,6 @@
 use crate::{
     vprintln, 
-    rgbimage, 
+    image::MarsImage, 
     enums, 
     path,
     constants,
@@ -14,7 +14,7 @@ pub fn process_file(input_file:&str,  only_new:bool) {
         return;
     }
     
-    let mut raw = rgbimage::RgbImage::open(String::from(input_file), enums::Instrument::M20HeliNav).unwrap();
+    let mut raw = MarsImage::open(String::from(input_file), enums::Instrument::M20HeliNav);
     
 
     let data_max = 255.0;
@@ -26,11 +26,11 @@ pub fn process_file(input_file:&str,  only_new:bool) {
     //}
 
     vprintln!("Flatfielding...");
-    raw.flatfield().unwrap();
+    raw.flatfield();
 
     vprintln!("Normalizing...");
-    raw.normalize_to_16bit_with_max(data_max).unwrap();
+    raw.image.normalize_to_16bit_with_max(data_max);
 
     vprintln!("Writing to disk...");
-    raw.save(&out_file).unwrap();
+    raw.save(&out_file);
 }
\ No newline at end of file
