@@ -3,4 +3,7 @@ pub mod scam;
 pub mod zcam;
 pub mod watson;
 pub mod remote;
-pub mod lmst;
\ No newline at end of file
+pub mod lmst;
+pub mod metadata;
+pub mod helinav;
+pub mod helirte;
\ No newline at end of file
