@@ -3,7 +3,9 @@ use crate::{
     jsonfetch, 
     error,
     util::*,
-    m20::metadata::*
+    m20::metadata::*,
+    metadata::convert_to_std_metadata,
+    path
 };
 
 
@@ -60,7 +62,8 @@ fn process_results(results:&M20ApiResults, thumbnails:bool, list_only:bool, sear
                 Err(e) => return Err(e)
             };
 
-            match save_image_json(&image.image_files.full_res, &image, only_new){
+            let image_base_name = path::basename(image.image_files.full_res.as_str());
+            match save_image_json(&image_base_name, &convert_to_std_metadata(image), only_new){
                 Ok(_) => (),
                 Err(e) => return Err(e)
             };
@@ -82,7 +85,8 @@ pub fn make_instrument_map() -> InstrumentMap {
         ("EDLCAM", vec!["EDL_DDCAM", "EDL_PUCAM1", "EDL_PUCAM2", "EDL_RUCAM", "EDL_RDCAM", "LCAM"]),
         ("WATSON", vec!["SHERLOC_WATSON"]),
         ("HELI_NAV", vec!["HELI_NAV"]),
-        ("HELI_RTE", vec!["HELI_RTE"])
+        ("HELI_RTE", vec!["HELI_RTE"]),
+        ("CACHECAM", vec!["CACHECAM"]),
     ].iter().cloned().collect()}
 }
 
