@@ -1,6 +1,6 @@
 use crate::{
     vprintln, 
-    rgbimage, 
+    image::MarsImage, 
     enums, 
     path,
     constants,
@@ -15,38 +15,38 @@ pub fn process_file(input_file:&str, red_scalar:f32, green_scalar:f32, blue_scal
         return;
     }
     
-    let mut raw = rgbimage::RgbImage::open(String::from(input_file), enums::Instrument::M20Watson).unwrap();
+    let mut raw = MarsImage::open(String::from(input_file), enums::Instrument::M20Watson);
     
     vprintln!("Inpainting...");
-    raw.apply_inpaint_fix().unwrap();
+    raw.apply_inpaint_fix();
 
     let mut data_max = 255.0;
 
     if ! no_ilt {
        vprintln!("Decompanding...");
-       raw.decompand().unwrap();
+       raw.decompand(&decompanding::ILT);
        data_max = decompanding::get_max_for_instrument(enums::Instrument::M20Watson) as f32;
     }
 
     //vprintln!("Flatfielding...");
     //raw.flatfield().unwrap();
     
-    if input_file.find("ECM") != None && raw.is_grayscale() {
+    if input_file.find("ECM") != None && raw.image.is_grayscale() {
         vprintln!("Image appears to be grayscale, applying debayering...");
-        raw.debayer().unwrap();
+        raw.debayer();
     }
 
     vprintln!("Applying color weights...");
-    raw.apply_weight(red_scalar, green_scalar, blue_scalar).unwrap();
+    raw.apply_weight(red_scalar, green_scalar, blue_scalar);
 
     vprintln!("Normalizing...");
-    raw.normalize_to_16bit_with_max(data_max).unwrap();
+    raw.image.normalize_to_16bit_with_max(data_max);
 
-    if raw.width == 1648 {
+    if raw.image.width == 1648 {
         vprintln!("Cropping...");
-        raw.crop(24, 4, 1600, 1192).unwrap();
+        raw.image.crop(24, 4, 1600, 1192);
     }
     
     vprintln!("Writing to disk...");
-    raw.save(&out_file).unwrap();
+    raw.save(&out_file);
 }
\ No newline at end of file
