@@ -1,6 +1,6 @@
 use crate::{
     vprintln, 
-    rgbimage, 
+    image::MarsImage, 
     enums, 
     path,
     decompanding,
@@ -15,28 +15,28 @@ pub fn process_file(input_file:&str, red_scalar:f32, green_scalar:f32, blue_scal
         return;
     }
 
-    let mut raw = rgbimage::RgbImage::open(String::from(input_file), enums::Instrument::MslMARDI).unwrap();
+    let mut raw = MarsImage::open(String::from(input_file), enums::Instrument::MslMARDI);
 
     let mut data_max = 255.0;
 
     if ! no_ilt {
         vprintln!("Decompanding...");
-        raw.decompand().unwrap();
+        raw.decompand(&decompanding::get_ilt_for_instrument(enums::Instrument::MslMARDI));
         data_max = decompanding::get_max_for_instrument(enums::Instrument::MslMARDI) as f32;
     }
 
     vprintln!("Flatfielding...");
-    raw.flatfield().unwrap();
+    raw.flatfield();
     
     vprintln!("Applying color weights...");
-    raw.apply_weight(red_scalar, green_scalar, blue_scalar).unwrap();
+    raw.apply_weight(red_scalar, green_scalar, blue_scalar);
 
     vprintln!("Cropping...");
-    raw.crop(24, 6, 1599, 1188).unwrap();
+    raw.image.crop(24, 6, 1599, 1188);
 
     vprintln!("Normalizing...");
-    raw.normalize_to_16bit_with_max(data_max).unwrap();
+    raw.image.normalize_to_16bit_with_max(data_max);
 
     vprintln!("Writing to disk...");
-    raw.save(&out_file).unwrap();
+    raw.save(&out_file);
 }
\ No newline at end of file
