@@ -5,7 +5,9 @@ use crate::{
     jsonfetch, 
     error,
     util::*,
-    msl::metadata::*
+    msl::metadata::*,
+    metadata::convert_to_std_metadata,
+    path
 };
 
 pub fn print_header() {
@@ -70,7 +72,9 @@ fn process_results(results:&MslApiResults, thumbnails:bool, list_only:bool, sear
                 Ok(_) => (),
                 Err(e) => return Err(e)
             };
-            match save_image_json(&image.url, &image, only_new){
+
+            let image_base_name = path::basename(image.url.as_str());
+            match save_image_json(&image_base_name, &convert_to_std_metadata(image), only_new){
                 Ok(_) => (),
                 Err(e) => return Err(e)
             };
