@@ -41,6 +41,34 @@ pub fn filename_char_at_pos(filename:&str, pos:usize) -> char {
     bn.chars().nth(pos).unwrap()
 }
 
+#[macro_export]
+macro_rules! max {
+    ($x: expr) => ($x);
+    ($x: expr, $($z: expr),+) => {{
+        let y = max!($($z),*);
+        if $x > y {
+            $x
+        } else {
+            y
+        }
+    }}
+}
+
+#[macro_export]
+macro_rules! min {
+    ($x: expr) => ($x);
+    ($x: expr, $($z: expr),+) => {{
+        let y = min!($($z),*);
+        if $x < y {
+            $x
+        } else {
+            y
+        }
+    }}
+}
+
+
+
 
 
 ////////////////////////////////////
@@ -170,19 +198,19 @@ pub fn save_image_json<T:Serialize>(image_url:&str, item:&T, only_new:bool) -> e
     save_image_json_from_string(&image_url, &item_str, only_new)
 }
 
-pub fn save_image_json_from_string(image_url:&str, item:&String, only_new:bool) -> error::Result<&'static str> {
-    let bn = path::basename(image_url);
-
-    let out_file = bn.replace(".jpg", "-metadata.json").replace(".JPG", "-metadata.json")
+pub fn save_image_json_from_string(image_path:&str, item:&String, only_new:bool) -> error::Result<&'static str> {
+    let out_file = image_path.replace(".jpg", "-metadata.json").replace(".JPG", "-metadata.json")
                              .replace(".png", "-metadata.json").replace(".PNG", "-metadata.json");
 
     if path::file_exists(out_file.as_str()) && only_new {
-        vprintln!("Output file {} exists, skipping", bn);
+        vprintln!("Output file {} exists, skipping", image_path);
         return ok!();
     }
 
     let path = Path::new(out_file.as_str());
 
+    vprintln!("Writing metadata file to {}", path.to_str().unwrap());
+
     let mut file = match File::create(&path) {
         Err(why) => panic!("couldn't create {}", why),
         Ok(file) => file,
@@ -196,13 +224,24 @@ pub fn save_image_json_from_string(image_url:&str, item:&String, only_new:bool)
 
 
 pub fn append_file_name(input_file:&str, append:&str) -> String {
-
     let append_with_ext = format!("-{}.png", append);
-    let out_file = input_file.replace(".png", append_with_ext.as_str())
-                             .replace(".PNG", append_with_ext.as_str())
-                             .replace(".jpg", append_with_ext.as_str())
-                             .replace(".JPG", append_with_ext.as_str())
-                             .replace(".tif", append_with_ext.as_str())
-                             .replace(".TIF", append_with_ext.as_str());
+    replace_image_extension(input_file, append_with_ext.as_str())
+    // let append_with_ext = format!("-{}.png", append);
+    // let out_file = input_file.replace(".png", append_with_ext.as_str())
+    //                          .replace(".PNG", append_with_ext.as_str())
+    //                          .replace(".jpg", append_with_ext.as_str())
+    //                          .replace(".JPG", append_with_ext.as_str())
+    //                          .replace(".tif", append_with_ext.as_str())
+    //                          .replace(".TIF", append_with_ext.as_str());
+    // String::from(out_file)
+}
+
+pub fn replace_image_extension(input_file:&str, append:&str) -> String {
+    let out_file = input_file.replace(".png", append)
+                             .replace(".PNG", append)
+                             .replace(".jpg", append)
+                             .replace(".JPG", append)
+                             .replace(".tif", append)
+                             .replace(".TIF", append);
     String::from(out_file)
 }
\ No newline at end of file
